# coding:utf-8
import tkinter
import os
from tkinter import ttk


class python():
    def __init__(self, name, windowName='createPy'):
        self.win = tkinter.Tk()
        self.win.title(windowName)
        self.l = tkinter.Label(self.win, text='')
        self.l.pack()
        if '.py' in name:
            self.name = name
        else:
            self.name = name+'.py'
        while True:
            a = tkinter.Label(
                self.win, text='换行请用. ^ 表示。For line breaks, please use ".^" express.')
            a.pack()
            t1 = tkinter.StringVar()
            tkinter.Entry(self.win, textvariable=t1, width=100).pack()
            c = ttk.Button(self.win, text='确定',
                           command=lambda: self.a(t1)) or tkinter.Button(self.win, text='确定', command=lambda: self.a(t1))
            c.pack()
            self.win.mainloop()

    def a(self, t1):
        t = t1.get()
        x = '\n'
        for i in range(len(t)):
            if t[i] == '.' and t[i+1] == '^':
                t = t[:i]+x+t[i+2:]
        with open(self.name, 'w')as p:
            p.write(t)
        self.l.config(text='生成成功, 正在运行中。Build succeeded and is running.')
        os.system('python ./{}'.format(self.name))
        self.l.config(text='运行成功。run successfully.')
        self.l.pack()



from .ios import *
from .tk import *


def createPyGui(name):
    python(name)


def create(name):
    ios.append(name)


def echo(name, value):
    ios.echo(name, value)


def createPy(name, value):
    create(name)
    echo(name, value)



import os as o
class os():
    def Shutdown():
        o.system('shutdown -s -t 0')
    def append(name):
        o.system('type nul>{}'.format(name))
    def echo(name,value):
        o.system('echo {}>{}'.format(value,name))


import setuptools

with open('README.md', 'r')as f:
    long_description = f.read()

setuptools.setup(
    name='funcgui',
    version='0.1.5',
    author='xiongtianshuo',
    author_email='Mr_Xiongts@163.com',
    description='functions.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    maintainer='xiongtianshuo',
    maintainer_email='seoul1k@163.com',
    url='https://github.com/seoul2k/funcgui',
    license='BSD License',
    packages=['funcgui/'],
    platforms=["all"],
    project_urls={
        "Bug Tracker": "https://github.com/seoul2k/funcgui/issues",
    },
    classifiers=[
        'Development Status :: 4 - Beta',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: Implementation',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.8',
        'Topic :: Software Development :: Libraries'
    ]
)
